@@ -47,7 +47,6 @@ describe 'keystone::resource::authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/revocation_cache_time').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('keystone_authtoken/signing_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
       end
     end
@@ -79,7 +78,6 @@ describe 'keystone::resource::authtoken' do
           :keyfile                      => 'somekey.key',
           :region_name                  => 'MyRegion',
           :revocation_cache_time        => '50',
-          :signing_dir                  => '/tmp/',
           :token_cache_time             => '20',
         })
       end
@@ -113,7 +111,6 @@ describe 'keystone::resource::authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/region_name').with_value(params[:region_name])
         is_expected.to contain_keystone_config('keystone_authtoken/revocation_cache_time').with_value(params[:revocation_cache_time])
-        is_expected.to contain_keystone_config('keystone_authtoken/signing_dir').with_value(params[:signing_dir])
         is_expected.to contain_keystone_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
       end
     end
@@ -144,9 +141,10 @@ describe 'keystone::resource::authtoken' do
           :memcache_pool_maxsize          => '10',
           :memcache_pool_dead_retry       => '300',
           :memcache_pool_conn_get_timeout => '10',
+          :manage_memcache_package        => true,
       })
       end
-      it 'configures memcahce severs in keystone authtoken' do
+      it 'configures memcache severs in keystone authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/memcached_servers').with_value( params[:memcached_servers] )
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_use_advanced_pool').with_value( params[:memcache_use_advanced_pool] )
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_security_strategy').with_value( params[:memcache_security_strategy] )
@@ -156,6 +154,10 @@ describe 'keystone::resource::authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_pool_maxsize').with_value( params[:memcache_pool_maxsize] )
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_pool_dead_retry').with_value( params[:memcache_pool_dead_retry] )
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_pool_conn_get_timeout').with_value( params[:memcache_pool_conn_get_timeout] )
+        is_expected.to contain_package('python-memcache').with(
+          :name   => 'python-memcache',
+          :ensure => 'present'
+        )
       end
     end
 
@@ -179,7 +181,7 @@ describe 'keystone::resource::authtoken' do
   end
 
   on_supported_os({
-    :supported_oos => OSDefaults.get_supported_os
+    :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
